Class: Gmail::Mailbox

Inherits:
Object show all
Defined in:
lib/gmail/mailbox.rb

Constant Summary collapse

MAILBOX_ALIASES =
{
  :all       => ['ALL'],
  :seen      => ['SEEN'],
  :unseen    => ['UNSEEN'],
  :read      => ['SEEN'],
  :unread    => ['UNSEEN'],
  :flagged   => ['FLAGGED'],
  :unflagged => ['UNFLAGGED'],
  :starred   => ['FLAGGED'],
  :unstarred => ['UNFLAGGED'], 
  :deleted   => ['DELETED'],
  :undeleted => ['UNDELETED'],
  :draft     => ['DRAFT'],
  :undrafted => ['UNDRAFT']
}

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(gmail, name = "INBOX") ⇒ Mailbox

Returns a new instance of Mailbox.



21
22
23
24
# File 'lib/gmail/mailbox.rb', line 21

def initialize(gmail, name="INBOX")
  @name  = name
  @gmail = gmail
end

Instance Attribute Details

#nameObject (readonly)

Returns the value of attribute name.



19
20
21
# File 'lib/gmail/mailbox.rb', line 19

def name
  @name
end

Instance Method Details

#count(*args) ⇒ Object

This is a convenience method that really probably shouldn't need to exist, but it does make code more readable, if seriously all you want is the count of messages.

Examples

gmail.inbox.count(:all)
gmail.inbox.count(:unread, :from => "[email protected]")
gmail.mailbox("Test").count(:all, :after => Time.now-(20*24*3600))


85
86
87
# File 'lib/gmail/mailbox.rb', line 85

def count(*args)
  emails(*args).size
end

#emails(*args, &block) ⇒ Object Also known as: mails, search, find, filter

Returns list of emails which meets given criteria.

Examples

gmail.inbox.emails(:all)
gmail.inbox.emails(:unread, :from => "[email protected]")
gmail.inbox.emails(:all, :after => Time.now-(20*24*3600))
gmail.mailbox("Test").emails(:read)

gmail.mailbox("Test") do |box| 
box.emails(:read)
box.emails(:unread) do |email|
  ... do something with each email...
end
end


41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/gmail/mailbox.rb', line 41

def emails(*args, &block)
  args << :all if args.size == 0

  if args.first.is_a?(Symbol) 
    search = MAILBOX_ALIASES[args.shift].dup
    opts = args.first.is_a?(Hash) ? args.first : {}
    
    opts[:after]      and search.concat ['SINCE', opts[:after].to_imap_date]
    opts[:before]     and search.concat ['BEFORE', opts[:before].to_imap_date]
    opts[:on]         and search.concat ['ON', opts[:on].to_imap_date]
    opts[:from]       and search.concat ['FROM', opts[:from]]
    opts[:to]         and search.concat ['TO', opts[:to]]
    opts[:subject]    and search.concat ['SUBJECT', opts[:subject]]
    opts[:label]      and search.concat ['LABEL', opts[:label]]
    opts[:attachment] and search.concat ['HAS', 'attachment']
    opts[:search]     and search.concat [opts[:search]]
    
    @gmail.mailbox(name) do
      @gmail.conn.uid_search(search).collect do |uid| 
        message = (messages[uid] ||= Message.new(self, uid))
        block.call(message) if block_given?
        message
      end
    end
  elsif args.first.is_a?(Hash)
    emails(:all, args.first)
  else
    raise ArgumentError, "Invalid search criteria"
  end
end

#expungeObject

This permanently removes messages which are marked as deleted



90
91
92
# File 'lib/gmail/mailbox.rb', line 90

def expunge
  @gmail.mailbox(name) { @gmail.conn.expunge }
end

#inspectObject



99
100
101
# File 'lib/gmail/mailbox.rb', line 99

def inspect
  "#<Gmail::Mailbox#{'0x%04x' % (object_id << 1)} name=#{@name}>"
end

#messagesObject

Cached messages.



95
96
97
# File 'lib/gmail/mailbox.rb', line 95

def messages
  @messages ||= {}
end

#to_sObject



103
104
105
# File 'lib/gmail/mailbox.rb', line 103

def to_s
  name
end